@@ -31,7 +31,7 @@ from threading import Barrier, Condition, Thread
 
 from .multipart import Data
 
-__version__ = "0.8"
+__version__ = "0.8.5"
 
 BASE_URL = "https://volafile.io"
 BASE_ROOM_URL = BASE_URL + "/r/"
@@ -60,6 +60,39 @@ def verify_username(username):
         raise ValueError("Usernames can only contain alphanumeric characters.")
 
 
+def parse_chat_message(data):
+    """Parses the data for a json chat message and returns a
+    ChatMessage object"""
+    nick = data['nick']
+    files = []
+    rooms = []
+    msg = ""
+    for part in data["message"]:
+        if part['type'] == 'text':
+            msg += part['value']
+        elif part['type'] == 'break':
+            msg += "\n"
+        elif part['type'] == 'file':
+            files += File(part['id'], part['name']),
+            msg += "@" + part['id']
+        elif part['type'] == 'room':
+            rooms += part["id"],
+            msg += "#" + part['id']
+        elif part['type'] == 'url':
+            msg += part['text']
+
+    options = data['options']
+    admin = 'admin' in options
+    user = 'user' in options or admin
+    donator = 'donator' in options
+
+    chat_message = ChatMessage(nick, msg, files, rooms,
+                               logged_in=user,
+                               donator=donator,
+                               admin=admin)
+    return chat_message
+
+
 class Connection(requests.Session):
 
     """Bundles a requests/websocket pair"""
@@ -329,31 +362,7 @@ class Room:
             elif data_type == "delete_file":
                 del self._files[item[0][1][1]]
             elif data_type == "chat":
-                nick = data['nick']
-                files = []
-                rooms = []
-                msg = ""
-                for part in data["message"]:
-                    if part['type'] == 'text':
-                        msg += part['value']
-                    elif part['type'] == 'file':
-                        files += File(part['id'], part['name']),
-                        msg += "@" + part['id']
-                    elif part['type'] == 'room':
-                        rooms += part["id"],
-                        msg += "#" + part['id']
-                    elif part['type'] == 'url':
-                        msg += part['text']
-
-                options = data['options']
-                admin = 'admin' in options
-                user = 'user' in options or admin
-                donator = 'donator' in options
-
-                chat_message = ChatMessage(nick, msg, files, rooms,
-                                           logged_in=user,
-                                           donator=donator,
-                                           admin=admin)
+                chat_message = parse_chat_message(data)
                 self.conn.enqueue_message(chat_message)
                 self._chat_log.append(chat_message)
 
@@ -387,9 +396,13 @@ class Room:
         return json.loads(self.conn.get(BASE_REST_URL + "getUserInfo",
                                         params={"name": name}).text)
 
-    def post_chat(self, msg):
-        """Posts a msg to this room's chat"""
-        self.conn.make_call("chat", [self.user.name, msg])
+    def post_chat(self, msg, me=False):
+        """Posts a msg to this room's chat. Set me=True if you want to /me"""
+        # pylint: disable=invalid-name
+        if not me:
+            self.conn.make_call("chat", [self.user.name, msg])
+        else:
+            self.conn.make_call("command", [self.name, "me", msg])
 
     def upload_file(self, filename, upload_as=None, blocksize=None,
                     callback=None):
@@ -422,6 +435,24 @@ class Room:
         if self.connected:
             self.conn.close()
 
+    def set_room_name(self, new_name):
+        """Sets the room name"""
+        if len(new_name) > 24 or len(new_name) < 1:
+            raise ValueError(
+                "Room name must be at most 24 characters and at least 1.")
+        self.conn.make_call("editInfo", [{"name": new_name}])
+
+    def set_room_private(self, private):
+        """Sets the room to private if given True, else sets to public"""
+        private = "true" if private else "false"
+        self.conn.make_call("editInfo", [{"private": private}])
+
+    def set_motd(self, motd):
+        """Sets the room's MOTD"""
+        if len(motd) > 1000:
+            raise ValueError("Room's MOTD must be at most 1000 characters")
+        self.conn.make_call("editInfo", [{"motd": motd}])
+
     def clear(self):
         """Clears the cached information, if any"""
         self._chat_log.clear()
